@@ -14,6 +14,7 @@ from . import equilibrium as eq
 from . import functional as fn
 from . import units_of_measure as thermo_units
 from .exceptions import DimensionError
+from chemicals.elements import array_to_atoms, atomic_index
 from . import utils
 
 __all__ = ('Stream', )
@@ -107,7 +108,7 @@ class Stream:
     The temperature, pressure and phase are attributes as well:
     
     >>> (s1.T, s1.P, s1.phase)
-    (298.15, 101325, 'l')
+    (298.15, 101325.0, 'l')
     
     The most convinient way to get and set flow rates is through
     the `get_flow` and `set_flow` methods:
@@ -144,17 +145,17 @@ class Stream:
     
     >>> s1.T += 10
     >>> s1.H
-    1083.4675869330183
+    1083.467954...
     
     Other thermodynamic properties are temperature and pressure dependent as well:
     
     >>> s1.rho # Density [kg/m3]
-    908.8914226175468
+    908.8914226...
     
     It may be more convinient to get properties with different units:
         
     >>> s1.get_property('rho', 'g/cm3')
-    0.9088914226175471
+    0.90889142...
     
     It is also possible to set some of the properties in different units:
         
@@ -166,12 +167,12 @@ class Stream:
         
     >>> bp = s1.bubble_point_at_P() # Bubble point at constant pressure
     >>> bp
-    BubblePointValues(T=357.0881141715846, P=101325, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.49 0.51])
+    BubblePointValues(T=357.09, P=101325, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.49 0.51])
     
     The bubble point results contain all results as attributes:
     
     >>> bp.T # Temperature [K]
-    357.0881141715846
+    357.088...
     >>> bp.y # Vapor composition
     array([0.49, 0.51])
     
@@ -249,7 +250,21 @@ class Stream:
         """Molar vapor fraction."""
         return 1.0 if self.phase.lower() == 'g' else 0.0
 
+    def isfeed(self):
+        """Return whether stream has a sink but no source."""
+        return bool(self._sink and not self._source)
+
+    def isproduct(self):
+        """Return whether stream has a source but no sink."""
+        return bool(self._source and not self._sink)
+
+    @property
+    def main_chemical(self):
+        """[str] ID of chemical with the largest mol fraction in stream."""
+        return self.chemicals.tuple[self.mol.argmax()].ID
+
     def disconnect(self):
+        """Disconnect stream from unit operations."""
         sink = self._sink
         source = self._source
         if sink:
@@ -263,7 +278,7 @@ class Stream:
     
     def _init_indexer(self, flow, phase, chemicals, chemical_flows):
         """Initialize molar flow rates."""
-        if flow is ():
+        if len(flow) == 0:
             if chemical_flows:
                 imol = indexer.ChemicalMolarFlowIndexer(phase, chemicals=chemicals, **chemical_flows)
             else:
@@ -307,6 +322,20 @@ class Stream:
 
     ### Property getters ###
 
+    def get_atomic_flow(self, symbol):
+        """
+        Return flow rate of atom in kmol / hr.
+        
+        """
+        return (self.chemicals.formula_array[atomic_index[symbol], :] * self.mol).sum()
+
+    def get_atomic_flows(self):
+        """
+        Return dictionary of atomic flow rates in kmol / hr.
+        
+        """
+        return array_to_atoms(self.chemicals.formula_array @ self.mol)
+
     def get_flow(self, units, key= ...):
         """
         Return an flow rates in requested units.
@@ -421,7 +450,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_property('sigma', 'N/m') # Surface tension
-        0.06384967976396348
+        0.063780393
 
         """
         value = getattr(self, name)
@@ -729,7 +758,7 @@ class Stream:
         return self._thermal_condition.in_equilibrium(other._thermal_condition)
     
     @classmethod
-    def sum(cls, streams):
+    def sum(cls, streams, ID=None, thermo=None):
         """
         Return a new Stream object that represents the sum of all given streams.
         
@@ -738,19 +767,19 @@ class Stream:
         >>> import thermosteam as tmo
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
-        >>> tmo.Stream.sum([s1, s1])
-        >>> s1.show(flow='kg/hr')
-        Stream: s1
+        >>> s_sum = tmo.Stream.sum([s1, s1], 's_sum')
+        >>> s_sum.show(flow='kg/hr')
+        Stream: s_sum
          phase: 'l', T: 298.15 K, P: 101325 Pa
          flow (kg/hr): Water    40
                        Ethanol  20
         
         """
         if streams:
-            new = streams[0].copy()
+            new = streams[0].copy(ID)
             new.mix_from(streams)
         else:
-            new = cls()
+            new = cls(ID, thermo=thermo)
         return new
     
     def mix_from(self, others):
@@ -1042,7 +1071,7 @@ class Stream:
         return new
     __copy__ = copy
     
-    def flow_proxy(self):
+    def flow_proxy(self, ID=None):
         """
         Return a new stream that shares flow rate data with this one.
         
@@ -1058,7 +1087,8 @@ class Stream:
         """
         cls = self.__class__
         new = cls.__new__(cls)
-        new._sink = new._source = new._ID = None
+        new.ID = None
+        new._sink = new._source = None
         new.price = 0
         new._thermo = self._thermo
         new._imol = imol = self._imol._copy_without_data()
@@ -1067,7 +1097,7 @@ class Stream:
         new._init_cache()
         return new
     
-    def proxy(self):
+    def proxy(self, ID=None):
         """
         Return a new stream that shares all data with this one.
         
@@ -1083,7 +1113,8 @@ class Stream:
         """
         cls = self.__class__
         new = cls.__new__(cls)
-        new._sink = new._source = new._ID = None
+        new.ID = None
+        new._sink = new._source = None
         new.price = self.price
         new._thermo = self._thermo
         new._imol = self._imol
@@ -1196,7 +1227,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_T()
-        BubblePointValues(T=350, P=76621.54388128179, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.486 0.514])
+        BubblePointValues(T=350.00, P=76622, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.486 0.514])
         
         """
         bp = self.get_bubble_point(IDs)
@@ -1218,7 +1249,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_P()
-        BubblePointValues(T=357.0881141715846, P=101325.0, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.49 0.51])
+        BubblePointValues(T=357.09, P=101325, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.49 0.51])
         
         """
         bp = self.get_bubble_point(IDs)
@@ -1242,7 +1273,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_T()
-        DewPointValues(T=350, P=48990.56398459762, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
+        DewPointValues(T=350.00, P=48991, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
         
         """
         dp = self.get_dew_point(IDs)
@@ -1266,7 +1297,7 @@ class Stream:
         >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_P()
-        DewPointValues(T=368.6573659718087, P=101325.0, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
+        DewPointValues(T=368.66, P=101325, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
         
         """
         dp = self.get_dew_point(IDs)
