@@ -9,19 +9,23 @@
 """
 from .utils import colors
 import flexsolve as flx
-from flexsolve.exceptions import *
 
-__all__ = (*flx.exceptions.__all__,
-           'UndefinedChemical',
+__all__ = ('UndefinedChemical',
            'UndefinedPhase',
            'DimensionError',
+           'InfeasibleRegion',
            'DomainError',
            'InvalidMethod',
-           'TargetUnsuccessful',
            'message_with_object_stamp',
            'try_method_with_object_stamp',
            'raise_error_with_object_stamp')
 
+class InfeasibleRegion(RuntimeError):
+    """Runtime error regarding infeasible processes."""
+    def __init__(self, region): 
+        self.region = region
+        super().__init__(region + ' is infeasible')
+
 class UndefinedChemical(AttributeError):
     """AttributeError regarding undefined chemicals."""
     def __init__(self, ID): super().__init__(repr(ID))
@@ -43,14 +47,6 @@ class InvalidMethod(ValueError):
     """ValueError regarding an attempt to evaluate an invalid method."""
     def __init__(self, method):
         super().__init__(repr(method))
-
-class TargetUnsuccessful(RuntimeError):
-    """RuntimeError regarding an algorithm not being able to reach a target specification."""
-    def __init__(self, name, target, value):
-        super().__init__(f"{name} target, {target}, could not be reached; value is {value}")
-        self.name = name
-        self.target = target
-        self.value = value
     
 def message_with_object_stamp(object, msg):
     object_name = str(repr(object))
